@@ -32,8 +32,18 @@ elif [[ "$1" == "shcdpy" ]]; then
 	./cluster/shcdpy.sh
 elif [[ "$1" == "shcsh" ]]; then
     ./cluster/shcsh.sh
-fi
 
+
+# multi-sites cluster
+elif [[ "$1" == "multimaster" ]]; then
+    ./cluster/multimaster.sh $2 $3 $4
+elif [[ "$1" == "siteindexer" ]]; then
+	# sleep 1m
+	./cluster/siteindexer.sh $2
+elif [[ "$1" == "sitesh" ]]; then
+	# sleep 1m
+	./cluster/sitesh.sh $2
+fi
 #if [ ! -f /.root_pw_set ]; then
 #        /set_root_pw.sh
 #fi
